==> Generic_Ubuntu_CX311_Drv_x86_x64_2.0.00.1401_20211124.zip: Generic_Ubuntu_CX311_Drv_x86_x64_2.0.00.1401_20211124/driver/include/aver_xilinx.h <==
/*===================================================================
 * Copyright(c) AVerMedia TECHNOLOGIES, Inc. 2017
 * All rights reserved
 * =================================================================
 * aver_xilinx.h
 *
 *  Created on: Apr 15, 2017
 *      Author: 
 *      Version:
 * =================================================================
 */
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

#ifndef AVER750_H
#define AVER750_H

#ifdef __cplusplus
extern "C" {
#endif

#include "rx_share.h"

#define AVER_XILINX_CXT_ID fourcc_id('A','V','E','R')
#define AVER_XILINX_GPIODRV_NAME "AVER_XILINX_GPIO"    

#define AUDIO_10MS_COUNT							1
#define BRIDGEAVER_XILINX_MAX_AUD_BUFFER_SIZE       0x2D00/4 //11520 //0xB400   // (48000*24/8*8) / (1000/40), 8ch 48k 24-bits, 40 ms buffer size
#define BRIDGEAVER_XILINX_MIN_MUTIPLE_AUD_BUFFER_SIZE_PCIEx2 8
#define BRIDGEAVER_XILINX_MIN_MUTIPLE_AUD_BUFFER_SIZE_PCIEx4 16

// [Jeff_070_20141212]
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE      BRIDGEAVER_XILINX_MAX_AUD_BUFFER_SIZE/4	// 10ms
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_48k_24	2880	//[AndyNien] Audio buffer size(48k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_48k_16	1920	//[AndyNien] Audio buffer size(48k, 16bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_44k_24	2646	//[AndyNien] Audio buffer size(44.1k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_44k_16	1764	//[AndyNien] Audio buffer size(44.1k, 16bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_32k_24	1920	//[AndyNien] Audio buffer size(32k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_32k_16	1280	//[AndyNien] Audio buffer size(32k, 16bit, 10ms)
    
typedef enum
{
	AVER_XILINX_I2C_BUS_0 = 0,
	AVER_XILINX_I2C_BUS_1,
	AVER_XILINX_I2C_BUS_2,
	AVER_XILINX_I2C_BUS_3,
	AVER_XILINX_I2C_BUS_4,
	AVER_XILINX_I2C_BUS_NUM,
} aver_xilinx_i2c_bus_e;

#if defined (AVER_CARD_CL311MN) || defined (AVER_CARD_CL311M2)
#define AVER_XILINX_I2C_BUS_NUM (AVER_XILINX_I2C_BUS_0 + 1)
#else
#define AVER_XILINX_I2C_BUS_NUM (AVER_XILINX_I2C_BUS_1 + 1)
#endif
typedef enum
{
    AVER_XILINX_GPIO_0,
    AVER_XILINX_GPIO_1,
    AVER_XILINX_GPIO_2,
    AVER_XILINX_GPIO_3,
    AVER_XILINX_GPIO_4,
    AVER_XILINX_GPIO_5,
    AVER_XILINX_GPIO_6,
    AVER_XILINX_GPIO_7,
    AVER_XILINX_GPIO_8,        
#if defined (AVER_CARD_CL311M2)
	AVER_XILINX_GPIO_9,
	AVER_XILINX_GPIO_10,
	AVER_XILINX_GPIO_11,
#endif
    AVER_XILINX_GPIO_NUM,            
}aver_xilinx_gpio_e;

typedef enum
{
    AVER_XILINX_GPIO_0_MASK=Bit(AVER_XILINX_GPIO_0),
    AVER_XILINX_GPIO_1_MASK=Bit(AVER_XILINX_GPIO_1),
    AVER_XILINX_GPIO_2_MASK=Bit(AVER_XILINX_GPIO_2),
    AVER_XILINX_GPIO_3_MASK=Bit(AVER_XILINX_GPIO_3),
    AVER_XILINX_GPIO_4_MASK=Bit(AVER_XILINX_GPIO_4),
    AVER_XILINX_GPIO_5_MASK=Bit(AVER_XILINX_GPIO_5),            
    AVER_XILINX_GPIO_6_MASK=Bit(AVER_XILINX_GPIO_6),
    AVER_XILINX_GPIO_7_MASK=Bit(AVER_XILINX_GPIO_7),
    AVER_XILINX_GPIO_8_MASK=Bit(AVER_XILINX_GPIO_8),
    AVER_XILINX_GPIO_MASK=((1<<8)-1),        
}aver_xilinx_gpio_mask_e;



typedef struct
{
    aver_xilinx_gpio_mask_e gpio_mask;
    aver_xilinx_gpio_mask_e gpio_value;
    int i2c_bus_speed[AVER_XILINX_I2C_BUS_NUM];
    U32_T  audio_buffer_size; 
}aver_xilinx_cfg_t;

typedef struct 
{
    int width;
    int height;
}framesize_t;

typedef struct
{
    int x;
    int y;
}pos_t;

#if defined (AVER_CARD_CL311MN)
typedef enum {
	AVER_XILINX_INPUT_0 = 0,
	AVER_XILINX_INPUT_1,
	AVER_XILINX_INPUT_2,
} aver_xilinx_input_e;
#elif defined (AVER_CARD_CL311M2)
typedef enum {
	AVER_XILINX_AUDIO_INPUT_0 = 0,
	AVER_XILINX_AUDIO_INPUT_1,
	AVER_XILINX_AUDIO_INPUT_2,
} aver_xilinx_audio_input_e;

typedef enum {
	AVER_XILINX_VIDEO_INPUT_0 = 0,
	AVER_XILINX_VIDEO_INPUT_1,
} aver_xilinx_video_input_e;
#endif

typedef enum {
    AVER_XILINX_CS_YUV422,
    AVER_XILINX_CS_YUV444,
    AVER_XILINX_CS_RGB_FULL,
    AVER_XILINX_CS_RGB_LIMITED,
    AVER_XILINX_CS_COUNT,        
}aver_xilinx_colorspace_e;

typedef enum
{
	AVER_XILINX_FMT_YUYV = 0,
	AVER_XILINX_FMT_UYVY, //1
	AVER_XILINX_FMT_YVYU, //2
	AVER_XILINX_FMT_VYUY, //3
	AVER_XILINX_FMT_YVU420, //4, YV12
	AVER_XILINX_FMT_YUV420, //5
	AVER_XILINX_FMT_NV12, //6
	AVER_XILINX_FMT_RGBP, //7
	AVER_XILINX_FMT_RGBR, //8
	AVER_XILINX_FMT_RGBO, //9
	AVER_XILINX_FMT_RGBQ, //10
	AVER_XILINX_FMT_RGB3, //11
	AVER_XILINX_FMT_BGR3, //12
	AVER_XILINX_FMT_RGB4, //13
	AVER_XILINX_FMT_BGR4, //14	
}aver_xilinx_pixfmt_e;

typedef struct
{
    aver_xilinx_colorspace_e colorspace;
    aver_xilinx_pixfmt_e pixel_format;
    int packet_colorspace;
    int yuv422_flag;
}aver_xilinx_video_csc_t;

typedef enum
{
    SCALER_CFG_VALID_MASK=(0x1<<0),
    CLIP_CFG_VALID_MASK=(0x1<<1),
    FRAMERATE_CFG_VALID_MASK=(0x1<<2), 
    SCALER_CFG_SHRINK_MASK=(0x1<<3),      
    CFG_VALID_ALL_MASK=(0x1<<4)-1,
    
}aver_xilinx_video_process_valid_mask_t;

typedef struct
{
    BOOL_T is_interlace;
    U8_T workingmode;
    U8_T colorspacemode;
    U8_T samplingmode;
    aver_xilinx_video_process_valid_mask_t valid_mask;
    framesize_t in_framesize;
    framesize_t out_framesize;
    framesize_t clip_size;
    pos_t clip_start;
    int audio_rate;
    int in_framerate; //added for check
    int out_framerate;
    aver_xilinx_colorspace_e colorspace_in;
    aver_xilinx_colorspace_e colorspace_out;
    aver_xilinx_pixfmt_e pixel_format_out;
    aver_xilinx_colorspace_e colorspace;
    aver_xilinx_pixfmt_e pixel_format;
    U32_T pixel_clock;
    int video_bypass;
    int dual_pixel;
    int packet_colorspace;
    int input_channel;
    int yuv422_flag;
    #if defined (AVER_CARD_CN312S)
    int line_buffer_size;
    #endif
}aver_xilinx_video_process_cfg_t;

typedef struct {
#if defined (AVER_CARD_CL311M2)
	aver_xilinx_audio_input_e input;
#elif defined (AVER_CARD_CL311MN)
	aver_xilinx_input_e input;
#endif
} aver_xilinx_audio_process_cfg_t;
typedef void (*aver_xilinx_audio_cb_t)(void *cxt,U8_T *buffer,U32_T size);

typedef struct
{
    aver_xilinx_audio_cb_t callback;
    void *asso_cxt;
}aver_xilinx_audio_cbinfo_t;

typedef struct
{
    BOOL_T is_interlace;
    U32_T width;
    U32_T height;
}aver_xilinx_frame_info_t;



typedef void (*aver_xilinx_callback_t)(void *);
#if defined (AVER_CARD_CN312S)
typedef void (*linebuffer_callback_t)(void *cxt,int buffer_modes,U32_T device_index,int buffer_index,int line_buffer_index,int line_buffer_size);
#endif

handle_t aver_xilinx_init(cxt_mgr_handle_t cxt_mgr,pci_model_handle_t pci_handle,aver_xilinx_cfg_t *setup_info);
void aver_xilinx_init_registers(handle_t aver_xilinx_handle, aver_xilinx_cfg_t *setup_info);
void aver_xilinx_stop(void* aver_xilinx_handle);
void aver_xilinx_start(void* aver_xilinx_handle);
void aver_xilinx_get_i2c_bus_cfg(handle_t aver_xilinx_handle,aver_xilinx_i2c_bus_e bus,i2c_model_bus_cfg_t *i2c_bus_cfg);
void aver_xilinx_enable_video_streaming(handle_t aver_xilinx_handle, BOOL_T enable,U32_T device_index,int image_attach);
void aver_xilinx_reset(handle_t aver_xilinx_handle,U32_T device_index);
void aver_xilinx_reset_new(handle_t aver_xilinx_handle, U32_T module, U32_T device_index);
void aver_xilinx_get_cardid(handle_t aver_xilinx_handle, U32_T *card_id);
void aver_xilinx_start_audio_streaming(handle_t aver_xilinx_handle,aver_xilinx_audio_cbinfo_t *cb_info,U32_T device_index);
void aver_xilinx_reconfigure_audio_streaming(handle_t aver_xilinx_handle, U32_T device_index);
void aver_xilinx_config_audio_process(handle_t aver_xilinx_handle, aver_xilinx_audio_process_cfg_t *aup_cfg); //new 0112
void aver_xilinx_stop_audio_streaming(handle_t aver_xilinx_handle,U32_T device_index);
void aver_xilinx_set_max_desc_count(handle_t aver_xilinx_handle,int max_desc_count,U32_T device_index);
void aver_xilinx_add_to_cur_desclist(handle_t aver_xilinx_handle,unsigned long phys_addr,unsigned size,U32_T device_index);
#if 1 //[RD3-144]+ //[AVTLD-72]+
// buf_info is the descriptor list of V4L2 buffer
// buf_info_count is the total number of buf_info
void aver_xilinx_translate_desclist(handle_t aver_xilinx_handle, void *buf_info, int buf_info_count, unsigned int size, unsigned int size_2, unsigned int size_3, U32_T device_index);
#endif //[RD3-144]- //[AVTLD-72]-
void aver_xilinx_active_current_desclist(handle_t aver_xilinx_handle,aver_xilinx_callback_t callback,void *cb_cxt,U32_T device_index);
void aver_xilinx_config_video_process(handle_t aver_xilinx_handle,aver_xilinx_video_process_cfg_t *vip_cfg,U32_T device_index);
#if defined (AVER_CARD_CL311M2)
void aver_xilinx_get_frameinfo(handle_t aver_xilinx_handle, aver_xilinx_frame_info_t *frameinfo, aver_xilinx_video_input_e input,U32_T device_index);
#else
void aver_xilinx_get_frameinfo(handle_t aver_xilinx_handle, aver_xilinx_frame_info_t *frameinfo, int *stable,U32_T device_index);
#endif
void aver_xilinx_get_audiorate(handle_t aver_xilinx_handle,U32_T *audiorate, U32_T framerate);
void aver_xilinx_set_audiorate(handle_t aver_xilinx_handle,int audiorate); 
void aver_xilinx_hdmi_hotplug(handle_t aver_xilinx_handle);
void aver_xilinx_hdmi_hotplug_old(handle_t aver_xilinx_handle);
int aver_xilinx_flash_dump(handle_t aver_xilinx_handle,int start_block, int blocks, U8_T *flash);
int aver_xilinx_flash_update(handle_t aver_xilinx_handle,int start_block, int blocks, U8_T *flash);
#if defined (AVER_CARD_CL311M2) || defined (AVER_CARD_CL311MN)
void aver_xilinx_vip_select_input(handle_t aver_xilinx_handle,int input);
void aver_xilinx_select_audio_input(handle_t aver_xilinx_handle, int input);
#endif
#if defined (AVER_CARD_CM311H)
void aver_xilinx_g_pin_code(handle_t aver_xilinx_handle, long* pin_code, long* subpin_code, int *device_id);
#endif

#if defined (AVER_CARD_CN312S)
void aver_xilinx_active_linebuffer(handle_t aver_xilinx_handle,aver_xilinx_callback_t callback,void *cb_cxt,U32_T device_index);
//void linebuffer_register_callback(handle_t aver_xilinx_handle,linebuffer_callback_t callback,void *cb_cxt,U32_T device_index);
#endif
void aver_xilinx_set_scaler(handle_t aver_xilinx_handle,U32_T width_out,U32_T height_out,U32_T width_in,U32_T height_in,BOOL_T is_interlace,U32_T device_index);

void aver_xilinx_g_fpga_info(handle_t aver_xilinx_handle,int *pmpid,int *version,int *flash_size,int *test_result);//ISP

void aver_xilinx_s_black_flag(handle_t aver_xilinx_handle,int extra_hdcp_black);
//void aver_xilinx_dual_pixel(handle_t aver_xilinx_handle,int csc_dual_pixel);
//void aver_xilinx_video_bypass(handle_t aver_xilinx_handle,int video_bypass);

int aver_xilinx_read_n_bytes_register(handle_t aver_xilinx_handle, unsigned int offset, unsigned char n_bytes, unsigned int *data);
int aver_xilinx_write_n_bytes_register(handle_t aver_xilinx_handle, unsigned int offset, unsigned char n_bytes, unsigned int data);
#ifdef __cplusplus
}
#endif

#endif /* AVER750_H */

==> Generic_Ubuntu_CX311_Drv_x86_x64_2.0.11_20210922.zip: Generic_Ubuntu_CX311_Drv_x86_x64_2.0.11_20210922/driver/include/aver_xilinx.h <==
/*===================================================================
 * Copyright(c) AVerMedia TECHNOLOGIES, Inc. 2017
 * All rights reserved
 * =================================================================
 * aver_xilinx.h
 *
 *  Created on: Apr 15, 2017
 *      Author: 
 *      Version:
 * =================================================================
 */
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

#ifndef AVER750_H
#define AVER750_H

#ifdef __cplusplus
extern "C" {
#endif

#include "rx_share.h"

#define AVER_XILINX_CXT_ID fourcc_id('A','V','E','R')
#define AVER_XILINX_GPIODRV_NAME "AVER_XILINX_GPIO"    

#define AUDIO_10MS_COUNT							1
#define BRIDGEAVER_XILINX_MAX_AUD_BUFFER_SIZE       0x2D00/4 //11520 //0xB400   // (48000*24/8*8) / (1000/40), 8ch 48k 24-bits, 40 ms buffer size
#define BRIDGEAVER_XILINX_MIN_MUTIPLE_AUD_BUFFER_SIZE_PCIEx2 8
#define BRIDGEAVER_XILINX_MIN_MUTIPLE_AUD_BUFFER_SIZE_PCIEx4 16

// [Jeff_070_20141212]
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE      BRIDGEAVER_XILINX_MAX_AUD_BUFFER_SIZE/4	// 10ms
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_48k_24	2880	//[AndyNien] Audio buffer size(48k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_48k_16	1920	//[AndyNien] Audio buffer size(48k, 16bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_44k_24	2646	//[AndyNien] Audio buffer size(44.1k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_44k_16	1764	//[AndyNien] Audio buffer size(44.1k, 16bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_32k_24	1920	//[AndyNien] Audio buffer size(32k, 24bit, 10ms)
#define BRIDGEAVER_XILINX_MAX_AUDCAP_BUFFER_SIZE_32k_16	1280	//[AndyNien] Audio buffer size(32k, 16bit, 10ms)
    
typedef enum
{
	AVER_XILINX_I2C_BUS_0 = 0,
	AVER_XILINX_I2C_BUS_1,
	AVER_XILINX_I2C_BUS_2,
	AVER_XILINX_I2C_BUS_3,
	AVER_XILINX_I2C_BUS_4,
	AVER_XILINX_I2C_BUS_NUM,
} aver_xilinx_i2c_bus_e;

#if defined (AVER_CARD_CL311MN) || defined (AVER_CARD_CL311M2)
#define AVER_XILINX_I2C_BUS_NUM (AVER_XILINX_I2C_BUS_0 + 1)
#else
#define AVER_XILINX_I2C_BUS_NUM (AVER_XILINX_I2C_BUS_1 + 1)
#endif
typedef enum
{
    AVER_XILINX_GPIO_0,
    AVER_XILINX_GPIO_1,
    AVER_XILINX_GPIO_2,
    AVER_XILINX_GPIO_3,
    AVER_XILINX_GPIO_4,
    AVER_XILINX_GPIO_5,
    AVER_XILINX_GPIO_6,
    AVER_XILINX_GPIO_7,
    AVER_XILINX_GPIO_8,        
#if defined (AVER_CARD_CL311M2)
	AVER_XILINX_GPIO_9,
	AVER_XILINX_GPIO_10,
	AVER_XILINX_GPIO_11,
#endif
    AVER_XILINX_GPIO_NUM,            
}aver_xilinx_gpio_e;

typedef enum
{
    AVER_XILINX_GPIO_0_MASK=Bit(AVER_XILINX_GPIO_0),
    AVER_XILINX_GPIO_1_MASK=Bit(AVER_XILINX_GPIO_1),
    AVER_XILINX_GPIO_2_MASK=Bit(AVER_XILINX_GPIO_2),
    AVER_XILINX_GPIO_3_MASK=Bit(AVER_XILINX_GPIO_3),
    AVER_XILINX_GPIO_4_MASK=Bit(AVER_XILINX_GPIO_4),
    AVER_XILINX_GPIO_5_MASK=Bit(AVER_XILINX_GPIO_5),            
    AVER_XILINX_GPIO_6_MASK=Bit(AVER_XILINX_GPIO_6),
    AVER_XILINX_GPIO_7_MASK=Bit(AVER_XILINX_GPIO_7),
    AVER_XILINX_GPIO_8_MASK=Bit(AVER_XILINX_GPIO_8),
    AVER_XILINX_GPIO_MASK=((1<<8)-1),        
}aver_xilinx_gpio_mask_e;



typedef struct
{
    aver_xilinx_gpio_mask_e gpio_mask;
    aver_xilinx_gpio_mask_e gpio_value;
    int i2c_bus_speed[AVER_XILINX_I2C_BUS_NUM];
    U32_T  audio_buffer_size; 
}aver_xilinx_cfg_t;

typedef struct 
{
    int width;
    int height;
}framesize_t;

typedef struct
{
    int x;
    int y;
}pos_t;

#if defined (AVER_CARD_CL311MN)
typedef enum {
	AVER_XILINX_INPUT_0 = 0,
	AVER_XILINX_INPUT_1,
	AVER_XILINX_INPUT_2,
} aver_xilinx_input_e;
#elif defined (AVER_CARD_CL311M2)
typedef enum {
	AVER_XILINX_AUDIO_INPUT_0 = 0,
	AVER_XILINX_AUDIO_INPUT_1,
	AVER_XILINX_AUDIO_INPUT_2,
} aver_xilinx_audio_input_e;

typedef enum {
	AVER_XILINX_VIDEO_INPUT_0 = 0,
	AVER_XILINX_VIDEO_INPUT_1,
} aver_xilinx_video_input_e;
#endif

typedef enum {
    AVER_XILINX_CS_YUV422,
    AVER_XILINX_CS_YUV444,
    AVER_XILINX_CS_RGB_FULL,
    AVER_XILINX_CS_RGB_LIMITED,
    AVER_XILINX_CS_COUNT,        
}aver_xilinx_colorspace_e;

typedef enum
{
	AVER_XILINX_FMT_YUYV = 0,
	AVER_XILINX_FMT_UYVY, //1
	AVER_XILINX_FMT_YVYU, //2
	AVER_XILINX_FMT_VYUY, //3
	AVER_XILINX_FMT_YVU420, //4, YV12
	AVER_XILINX_FMT_YUV420, //5
	AVER_XILINX_FMT_NV12, //6
	AVER_XILINX_FMT_RGBP, //7
	AVER_XILINX_FMT_RGBR, //8
	AVER_XILINX_FMT_RGBO, //9
	AVER_XILINX_FMT_RGBQ, //10
	AVER_XILINX_FMT_RGB3, //11
	AVER_XILINX_FMT_BGR3, //12
	AVER_XILINX_FMT_RGB4, //13
	AVER_XILINX_FMT_BGR4, //14	
}aver_xilinx_pixfmt_e;

typedef struct
{
    aver_xilinx_colorspace_e colorspace;
    aver_xilinx_pixfmt_e pixel_format;
    int packet_colorspace;
    int yuv422_flag;
}aver_xilinx_video_csc_t;

typedef enum
{
    SCALER_CFG_VALID_MASK=(0x1<<0),
    CLIP_CFG_VALID_MASK=(0x1<<1),
    FRAMERATE_CFG_VALID_MASK=(0x1<<2), 
    SCALER_CFG_SHRINK_MASK=(0x1<<3),      
    CFG_VALID_ALL_MASK=(0x1<<4)-1,
    
}aver_xilinx_video_process_valid_mask_t;

typedef struct
{
    BOOL_T is_interlace;
    U8_T workingmode;
    U8_T colorspacemode;
    U8_T samplingmode;
    aver_xilinx_video_process_valid_mask_t valid_mask;
    framesize_t in_framesize;
    framesize_t out_framesize;
    framesize_t clip_size;
    pos_t clip_start;
    int audio_rate;
    int in_framerate; //added for check
    int out_framerate;
    aver_xilinx_colorspace_e colorspace_in;
    aver_xilinx_colorspace_e colorspace_out;
    aver_xilinx_pixfmt_e pixel_format_out;
    aver_xilinx_colorspace_e colorspace;
    aver_xilinx_pixfmt_e pixel_format;
    U32_T pixel_clock;
    int video_bypass;
    int dual_pixel;
    int packet_colorspace;
    int input_channel;
    int yuv422_flag;
    #if defined (AVER_CARD_CN312S)
    int line_buffer_size;
    #endif
}aver_xilinx_video_process_cfg_t;

typedef struct {
#if defined (AVER_CARD_CL311M2)
	aver_xilinx_audio_input_e input;
#elif defined (AVER_CARD_CL311MN)
	aver_xilinx_input_e input;
#endif
} aver_xilinx_audio_process_cfg_t;
typedef void (*aver_xilinx_audio_cb_t)(void *cxt,U8_T *buffer,U32_T size);

typedef struct
{
    aver_xilinx_audio_cb_t callback;
    void *asso_cxt;
}aver_xilinx_audio_cbinfo_t;

typedef struct
{
    BOOL_T is_interlace;
    U32_T width;
    U32_T height;
}aver_xilinx_frame_info_t;



typedef void (*aver_xilinx_callback_t)(void *);
#if defined (AVER_CARD_CN312S)
typedef void (*linebuffer_callback_t)(void *cxt,int buffer_modes,U32_T device_index,int buffer_index,int line_buffer_index,int line_buffer_size);
#endif

handle_t aver_xilinx_init(cxt_mgr_handle_t cxt_mgr,pci_model_handle_t pci_handle,aver_xilinx_cfg_t *setup_info);
void aver_xilinx_init_registers(handle_t aver_xilinx_handle, aver_xilinx_cfg_t *setup_info);
void aver_xilinx_stop(void* aver_xilinx_handle);
void aver_xilinx_start(void* aver_xilinx_handle);
void aver_xilinx_get_i2c_bus_cfg(handle_t aver_xilinx_handle,aver_xilinx_i2c_bus_e bus,i2c_model_bus_cfg_t *i2c_bus_cfg);
void aver_xilinx_enable_video_streaming(handle_t aver_xilinx_handle, BOOL_T enable,U32_T device_index,int image_attach);
void aver_xilinx_reset(handle_t aver_xilinx_handle,U32_T device_index);
void aver_xilinx_reset_new(handle_t aver_xilinx_handle, U32_T module, U32_T device_index);
void aver_xilinx_get_cardid(handle_t aver_xilinx_handle, U32_T *card_id);
void aver_xilinx_start_audio_streaming(handle_t aver_xilinx_handle,aver_xilinx_audio_cbinfo_t *cb_info,U32_T device_index);
void aver_xilinx_reconfigure_audio_streaming(handle_t aver_xilinx_handle, U32_T device_index);
void aver_xilinx_config_audio_process(handle_t aver_xilinx_handle, aver_xilinx_audio_process_cfg_t *aup_cfg); //new 0112
void aver_xilinx_stop_audio_streaming(handle_t aver_xilinx_handle,U32_T device_index);
void aver_xilinx_set_max_desc_count(handle_t aver_xilinx_handle,int max_desc_count,U32_T device_index);
void aver_xilinx_add_to_cur_desclist(handle_t aver_xilinx_handle,unsigned long phys_addr,unsigned size,U32_T device_index);
#if 1 //[RD3-144]+ //[AVTLD-72]+
// buf_info is the descriptor list of V4L2 buffer
// buf_info_count is the total number of buf_info
void aver_xilinx_translate_desclist(handle_t aver_xilinx_handle, void *buf_info, int buf_info_count, unsigned int size, unsigned int size_2, unsigned int size_3, U32_T device_index);
#endif //[RD3-144]- //[AVTLD-72]-
void aver_xilinx_active_current_desclist(handle_t aver_xilinx_handle,aver_xilinx_callback_t callback,void *cb_cxt,U32_T device_index);
void aver_xilinx_config_video_process(handle_t aver_xilinx_handle,aver_xilinx_video_process_cfg_t *vip_cfg,U32_T device_index);
#if defined (AVER_CARD_CL311M2)
void aver_xilinx_get_frameinfo(handle_t aver_xilinx_handle, aver_xilinx_frame_info_t *frameinfo, aver_xilinx_video_input_e input,U32_T device_index);
#else
void aver_xilinx_get_frameinfo(handle_t aver_xilinx_handle, aver_xilinx_frame_info_t *frameinfo, int *stable,U32_T device_index);
#endif
void aver_xilinx_get_audiorate(handle_t aver_xilinx_handle,U32_T *audiorate, U32_T framerate);
void aver_xilinx_set_audiorate(handle_t aver_xilinx_handle,int audiorate); 
void aver_xilinx_hdmi_hotplug(handle_t aver_xilinx_handle);
void aver_xilinx_hdmi_hotplug_old(handle_t aver_xilinx_handle);
int aver_xilinx_flash_dump(handle_t aver_xilinx_handle,int start_block, int blocks, U8_T *flash);
int aver_xilinx_flash_update(handle_t aver_xilinx_handle,int start_block, int blocks, U8_T *flash);
#if defined (AVER_CARD_CL311M2) || defined (AVER_CARD_CL311MN)
void aver_xilinx_vip_select_input(handle_t aver_xilinx_handle,int input);
void aver_xilinx_select_audio_input(handle_t aver_xilinx_handle, int input);
#endif
#if defined (AVER_CARD_CM311H)
void aver_xilinx_g_pin_code(handle_t aver_xilinx_handle, long* pin_code, long* subpin_code, int *device_id);
#endif

#if defined (AVER_CARD_CN312S)
void aver_xilinx_active_linebuffer(handle_t aver_xilinx_handle,aver_xilinx_callback_t callback,void *cb_cxt,U32_T device_index);
void linebuffer_register_callback(handle_t aver_xilinx_handle,linebuffer_callback_t callback,void *cb_cxt,U32_T device_index);
#endif
void aver_xilinx_set_scaler(handle_t aver_xilinx_handle,U32_T width_out,U32_T height_out,U32_T width_in,U32_T height_in,BOOL_T is_interlace,U32_T device_index);

void aver_xilinx_g_fpga_info(handle_t aver_xilinx_handle,int *pmpid,int *version,int *flash_size,int *test_result);//ISP

void aver_xilinx_s_black_flag(handle_t aver_xilinx_handle,int extra_hdcp_black);
//void aver_xilinx_dual_pixel(handle_t aver_xilinx_handle,int csc_dual_pixel);
//void aver_xilinx_video_bypass(handle_t aver_xilinx_handle,int video_bypass);

int aver_xilinx_read_n_bytes_register(handle_t aver_xilinx_handle, unsigned int offset, unsigned char n_bytes, unsigned int *data);
int aver_xilinx_write_n_bytes_register(handle_t aver_xilinx_handle, unsigned int offset, unsigned char n_bytes, unsigned int data);
#ifdef __cplusplus
}
#endif

#endif /* AVER750_H */
